@@ -61,9 +61,14 @@
 #include <stdlib.h>
 #include <string.h>
 
+/* Darwin doesn't export environ */
+#if defined(__darwin__)
+#define environ (*_NSGetEnviron())
+#else
 extern char **environ;
+#endif
+
 bool        update_process_title = true;
-static bool IsUnderPostmaster = true;
 
 /*
  * Alternative ways of updating ps display:
@@ -114,7 +119,7 @@ static bool IsUnderPostmaster = true;
 #endif
 
 /* Different systems want the buffer padded differently */
-#if defined(_AIX) || defined(__linux__) || defined(__svr4__)
+#if defined(_AIX) || defined(__linux__) || defined(__svr4__) || defined(__darwin__)
 #define PS_PADDING '\0'
 #else
 #define PS_PADDING ' '
@@ -157,6 +162,11 @@ save_ps_display_args(int argc, char **argv)
 
 #if defined(PS_USE_CLOBBER_ARGV)
 
+#if defined(__darwin__)
+	/* Darwin doesn't export the environ variable */
+	environ = *_NSGetEnviron();
+#endif
+
     /*
      * If we're going to overwrite the argv area, count the available space.
      * Also move the environment to make additional room.
@@ -253,10 +263,6 @@ init_ps_display(const char *initial_str)
 {
 
 #ifndef PS_USE_NONE
-    /* no ps display for stand-alone backend */
-    if (!IsUnderPostmaster)
-        return;
-
     /* no ps display if you didn't call save_ps_display_args() */
     if (!save_argv)
         return;
@@ -311,9 +317,6 @@ set_ps_display(const char *activity, bool force)
         return;
 
 #ifndef PS_USE_NONE
-    /* no ps display for stand-alone backend */
-    if (!IsUnderPostmaster)
-        return;
 
 #ifdef PS_USE_CLOBBER_ARGV
     /* If ps_buffer is a pointer, it might still be null */
